"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.collectUserFlowsCommand = void 0;
const tslib_1 = require("tslib");
const user_flow_1 = require("../../internal/utils/user-flow");
const constants_1 = require("../../internal/config/constants");
const index_1 = require("../../core/loggin/index");
const interactive_1 = require("../../core/options/interactive");
const dryRun_1 = require("../../core/options/dryRun");
const open_1 = require("./options/open");
const openFileInBrowser = require("open");
const options_1 = require("./options");
exports.collectUserFlowsCommand = {
    command: 'collect',
    description: 'Run a set of user flows and save the result',
    builder: (y) => y.options(options_1.COLLECT_OPTIONS).help(),
    module: {
        handler: (argv) => (0, tslib_1.__awaiter)(void 0, void 0, void 0, function* () {
            (0, index_1.logVerbose)(`run "collect" as a yargs command with args:`);
            (0, index_1.logVerbose)(argv);
            const { url, ufPath, outPath, open: openReport } = argv;
            yield run({ url, ufPath, outPath, openReport });
        })
    }
};
function run(cfg) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let { url, ufPath, outPath } = cfg;
        outPath = outPath || constants_1.USER_FLOW_RESULT_DIR;
        // Check if url is given
        if (!url) {
            throw new Error('URL is required. Either through the console as `--url` or in the `.user-flow.json`');
        }
        // Check if path to user-flows is given
        if (!ufPath) {
            throw new Error('Path to user flows is required. Either through the console as `--ufPath` or in the `.user-flowrc.json`');
        }
        // Load and run user-flows in parallel
        const userFlows = (0, user_flow_1.loadFlow)(ufPath);
        yield sequeltial(userFlows.map(({ exports: provider, path }) => (_) => (0, user_flow_1.collectFlow)({ url, ufPath }, Object.assign(Object.assign({}, provider), { path }))
            .then((flow) => !(0, dryRun_1.get)() ? (0, user_flow_1.persistFlow)(flow, provider.flowOptions.name, { outPath }) : '')
            .then((fileName) => {
            // open report if requested and not in executed in CI
            if (!(0, dryRun_1.get)() && (0, open_1.get)() && (0, interactive_1.get)()) {
                openFileInBrowser(fileName, { wait: false });
            }
        })));
    });
}
exports.run = run;
function sequeltial(set) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        let res = undefined;
        for (let i = 0; i < set.length; i++) {
            res = yield set[i](res);
        }
    });
}
//# sourceMappingURL=collect.js.map