"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toFileName = exports.resolveAnyFile = exports.writeFile = exports.readFile = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const loggin_1 = require("../../core/loggin");
/**
 * Ensures the file exists before reading it
 */
function readFile(path) {
    if ((0, fs_1.existsSync)(path)) {
        return (0, fs_1.readFileSync)(path, 'utf-8');
    }
    (0, loggin_1.logVerbose)(path + ' does not exist.');
    return '';
}
exports.readFile = readFile;
/**
 * Ensures the folder exists before writing it
 */
function writeFile(path, data) {
    const dir = (0, path_1.dirname)(path);
    if (!(0, fs_1.existsSync)(dir)) {
        (0, fs_1.mkdirSync)(dir);
    }
    return (0, fs_1.writeFileSync)(path, data);
}
exports.writeFile = writeFile;
function resolveAnyFile(path) {
    // start path from cwd
    path = (0, path_1.join)(process.cwd(), path);
    let file;
    // 🔥 Live compilation of TypeScript files
    if (path.endsWith('.ts')) {
        // Register TS compiler lazily
        // tsNode needs the compilerOptions.module resolution to be 'commonjs',
        // so that imports in the `*.uf.ts` files work.
        require('ts-node').register({
            "compilerOptions": {
                "module": "commonjs"
            }
        });
    }
    file = require(path);
    // If the user provides a configuration in TS file
    // then there are 2 cases for exporing an object. The first one is:
    // `module.exports = { ... }`. And the second one is:
    // `export default { ... }`. The ESM format is compiled into:
    // `{ default: { ... } }`
    const exports = file.default || file;
    return { exports, path };
}
exports.resolveAnyFile = resolveAnyFile;
/**
 * Upper or camelCase to lowercase hyphenated
 */
function toFileName(s) {
    return s
        .replace(/([a-z\d])([A-Z])/g, '$1_$2')
        .toLowerCase()
        .replace(/[ _]/g, '-')
        .replace(/[/\\]/g, '-');
}
exports.toFileName = toFileName;
//# sourceMappingURL=file.js.map